@@ -2,17 +2,18 @@
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 from __future__ import absolute_import
 import re
-import os
 import hashlib
 import random
+import logging
+from urllib.parse import urlparse
 
 from svtplay_dl.service import Service
 from svtplay_dl.fetcher.hls import hlsparse
-from svtplay_dl.subtitle import subtitle
-from svtplay_dl.utils.urllib import urlparse
 from svtplay_dl.error import ServiceError
-from svtplay_dl.utils import filenamify, is_py2
-from svtplay_dl.log import log
+from svtplay_dl.subtitle import subtitle
+
+
+country = {"sv": ".se", "da": ".dk", "no": ".no"}
 
 
 class Dplay(Service):
@@ -23,12 +24,12 @@ class Dplay(Service):
         self.domain = re.search(r"(dplay\.\w\w)", parse.netloc).group(1)
 
         if not self._token():
-            log.error("Something went wrong getting token for requests")
+            logging.error("Something went wrong getting token for requests")
 
-        if self.options.username and self.options.password:
+        if self.config.get("username") and self.config.get("password"):
             premium = self._login()
             if not premium:
-                log.warning("Wrong username/password.")
+                logging.warning("Wrong username/password.")
 
         channel = False
         if "kanaler" in parse.path:
@@ -36,7 +37,7 @@ class Dplay(Service):
             path = "/channels/{}".format(match.group(1))
             url = "https://disco-api.{}/content{}".format(self.domain, path)
             channel = True
-            self.options.live = True
+            self.config.set("live", True)
         elif "program" in parse.path:
             match = re.search("(programmer|program)/([^/]+)$", parse.path)
             path = "/shows/{}".format(match.group(2))
@@ -67,68 +68,58 @@ class Dplay(Service):
             yield ServiceError("Cant find any videos on this url")
             return
 
-        if self.options.output_auto:
-            directory = os.path.dirname(self.options.output)
-            self.options.service = "dplay"
-            if channel:
-                name = filenamify(janson["data"]["attributes"]["name"])
-            else:
-                name = self._autoname(janson)
-            if name is None:
-                yield ServiceError("Cant find vid id for autonaming")
-                return
-            title = "{0}-{1}-{2}".format(name, janson["data"]["id"], self.options.service)
-            if len(directory):
-                self.options.output = os.path.join(directory, title)
-            else:
-                self.options.output = title
-
-        if self.exclude():
-            yield ServiceError("Excluding video")
+        if channel:
+            name = janson["data"]["attributes"]["name"]
+            self.output["title"] = name
+        else:
+            name = self._autoname(janson)
+        if name is None:
+            yield ServiceError("Cant find vid id for autonaming")
             return
+        self.output["id"] = janson["data"]["id"]
 
         api = "https://disco-api.{}/playback/videoPlaybackInfo/{}".format(self.domain, janson["data"]["id"])
         res = self.http.get(api)
         if res.status_code > 400:
             yield ServiceError("You dont have permission to watch this")
             return
-        streams = hlsparse(self.options, self.http.request("get", res.json()["data"]["attributes"]["streaming"]["hls"]["url"]),
-                           res.json()["data"]["attributes"]["streaming"]["hls"]["url"], httpobject=self.http)
-        if streams:
-            for n in list(streams.keys()):
+        streams = hlsparse(self.config, self.http.request("get", res.json()["data"]["attributes"]["streaming"]["hls"]["url"]),
+                           res.json()["data"]["attributes"]["streaming"]["hls"]["url"], httpobject=self.http, output=self.output)
+        for n in list(streams.keys()):
+            if isinstance(streams[n], subtitle):  # we get the subtitles from the hls playlist.
+                if self.config.get("get_all_subtitles"):
+                    yield streams[n]
+                else:
+                    if streams[n].subfix in country and country[streams[n].subfix] in self.domain:
+                        yield streams[n]
+            else:
                 yield streams[n]
 
     def _autoname(self, jsondata):
         match = re.search('^([^/]+)/', jsondata["data"]["attributes"]["path"])
-        show = match.group(1)
-        season = jsondata["data"]["attributes"]["seasonNumber"]
-        episode = jsondata["data"]["attributes"]["episodeNumber"]
-        name = jsondata["data"]["attributes"]["name"]
-        if is_py2:
-            show = filenamify(show).encode("latin1")
-            name = filenamify(name).encode("latin1")
-        else:
-            show = filenamify(show)
+        self.output["title"] = match.group(1)
+        self.output["season"] = int(jsondata["data"]["attributes"]["seasonNumber"])
+        self.output["episode"] = int(jsondata["data"]["attributes"]["episodeNumber"])
+        self.output["episodename"] = jsondata["data"]["attributes"]["name"]
+        return self.output["title"]
 
-        return filenamify("{0}.s{1:02d}e{2:02d}.{3}".format(show, int(season), int(episode), name))
-
-    def find_all_episodes(self, options):
+    def find_all_episodes(self, config):
         parse = urlparse(self.url)
         self.domain = re.search(r"(dplay\.\w\w)", parse.netloc).group(1)
 
         match = re.search("^/(program|programmer|videos|videoer)/([^/]+)", parse.path)
         if not match:
-            log.error("Can't find show name")
+            logging.error("Can't find show name")
             return None
 
         if not self._token():
-            log.error("Something went wrong getting token for requests")
+            logging.error("Something went wrong getting token for requests")
 
         premium = False
-        if self.options.username and self.options.password:
+        if self.config.get("username") and self.config.get("password"):
             premium = self._login()
             if not premium:
-                log.warning("Wrong username/password.")
+                logging.warning("Wrong username/password.")
 
         url = "https://disco-api.{}/content/shows/{}".format(self.domain, match.group(2))
         res = self.http.get(url)
@@ -141,18 +132,18 @@ class Dplay(Service):
             res = self.http.get("https://disco-api.{}/content/videos?{}".format(self.domain, qyerystring))
             janson = res.json()
             for i in janson["data"]:
-                if not premium and not "Free" in i["attributes"]["packages"]:
+                if not premium and "Free" not in i["attributes"]["packages"]:
                     continue
                 episodes.append("https://www.{}/videos/{}".format(self.domain, i["attributes"]["path"]))
         if len(episodes) == 0:
-            log.error("Cant find any playable files")
-        if options.all_last > 0:
-            return episodes[:options.all_last]
+            logging.error("Cant find any playable files")
+        if config.get("all_last") > 0:
+            return episodes[:config.get("all_last")]
         return episodes
 
     def _login(self):
         url = "https://disco-api.{}/login".format(self.domain)
-        login = {"credentials": {"username": self.options.username, "password": self.options.password}}
+        login = {"credentials": {"username": self.config.get("username"), "password": self.config.get("password")}}
         res = self.http.post(url, json=login)
         if res.status_code > 400:
             return False
@@ -160,7 +151,7 @@ class Dplay(Service):
 
     def _token(self):
         # random device id for cookietoken
-        deviceid = hashlib.sha256(bytes(int(random.random()*1000))).hexdigest()
+        deviceid = hashlib.sha256(bytes(int(random.random() * 1000))).hexdigest()
         url = "https://disco-api.{}/token?realm={}&deviceId={}&shortlived=true".format(self.domain, self.domain.replace(".", ""), deviceid)
         res = self.http.get(url)
         if res.status_code > 400:
