@@ -5,10 +5,9 @@ import re
 import json
 
 from svtplay_dl.service import Service
-from svtplay_dl.error import ServiceError
 from svtplay_dl.log import log
 from svtplay_dl.fetcher.hls import hlsparse
-from svtplay_dl.utils import decode_html_entities
+from svtplay_dl.utils.text import decode_html_entities
 
 
 class Expressen(Service):
@@ -17,10 +16,6 @@ class Expressen(Service):
     def get(self):
         data = self.get_urldata()
 
-        if self.exclude():
-            yield ServiceError("Excluding video")
-            return
-
         match = re.search('="(https://www.expressen.se/tvspelare[^"]+)"', data)
         if not match:
             log.error("Can't find video id")
@@ -35,10 +30,12 @@ class Expressen(Service):
         dataj = json.loads(match.group(1))
         if "streams" in dataj:
             if "iPad" in dataj["streams"]:
-                streams = hlsparse(self.options, self.http.request("get", dataj["streams"]["iPad"]), dataj["streams"]["iPad"])
+                streams = hlsparse(self.config, self.http.request("get", dataj["streams"]["iPad"]),
+                                   dataj["streams"]["iPad"], output=self.output)
                 for n in list(streams.keys()):
                     yield streams[n]
             if "hashHls" in dataj["streams"]:
-                streams = hlsparse(self.options, self.http.request("get", dataj["streams"]["hashHls"]), dataj["streams"]["hashHls"])
+                streams = hlsparse(self.config, self.http.request("get", dataj["streams"]["hashHls"]),
+                                   dataj["streams"]["hashHls"], output=self.output)
                 for n in list(streams.keys()):
                     yield streams[n]
