@@ -7,7 +7,7 @@ import json
 from svtplay_dl.service import Service
 from svtplay_dl.error import ServiceError
 from svtplay_dl.fetcher.hls import hlsparse
-from svtplay_dl.utils import decode_html_entities
+from svtplay_dl.utils.text import decode_html_entities
 
 
 class Lemonwhale(Service):
@@ -15,10 +15,6 @@ class Lemonwhale(Service):
     supported_domains = ['vk.se', 'lemonwhale.com']
 
     def get(self):
-        if self.exclude():
-            yield ServiceError("Excluding video")
-            return
-
         vid = self.get_vid()
         if not vid:
             yield ServiceError("Can't find video id")
@@ -38,9 +34,8 @@ class Lemonwhale(Service):
         jdata = json.loads(data)
         if "videos" in jdata:
             streams = self.get_video(jdata)
-            if streams:
-                for n in list(streams.keys()):
-                    yield streams[n]
+            for n in list(streams.keys()):
+                yield streams[n]
 
     def get_vid(self):
         match = re.search(r'video url-([^"]+)', self.get_urldata())
@@ -63,5 +58,5 @@ class Lemonwhale(Service):
         for i in videos:
             if i["name"] == "auto":
                 hls = "{0}{1}".format(janson["videos"][0]["media"]["base"], i["url"])
-        streams = hlsparse(self.options, self.http.request("get", hls), hls)
+        streams = hlsparse(self.config, self.http.request("get", hls), hls, output=self.output)
         return streams
