@@ -1,21 +1,18 @@
 from __future__ import absolute_import
 import re
 import json
+from urllib.parse import urljoin
 
 from svtplay_dl.service import Service, OpenGraphThumbMixin
 from svtplay_dl.fetcher.hls import hlsparse
 from svtplay_dl.error import ServiceError
-from svtplay_dl.utils.urllib import urljoin
 
 
 class NHL(Service, OpenGraphThumbMixin):
     supported_domains = ['nhl.com']
 
     def get(self):
-        if self.exclude():
-            yield ServiceError("Excluding video")
-            return
-        match = re.search("var initialMedia\s+= ({[^;]+);", self.get_urldata())
+        match = re.search(r"var initialMedia\s+= ({[^;]+);", self.get_urldata())
         if not match:
             yield ServiceError("Cant find any media on that page")
             return
@@ -27,12 +24,12 @@ class NHL(Service, OpenGraphThumbMixin):
         if "playbacks" in janson["metaData"]:
             for i in janson["metaData"]["playbacks"]:
                 if "CLOUD" in i["name"]:
-                    streams = hlsparse(self.options, self.http.request("get", i["url"]), i["url"])
+                    streams = hlsparse(self.config, self.http.request("get", i["url"]), i["url"])
                     if streams:
                         for n in list(streams.keys()):
                             yield streams[n]
         else:
-            match = re.search("var mediaConfig\s+= ({[^;]+);", self.get_urldata())
+            match = re.search(r"var mediaConfig\s+= ({[^;]+);", self.get_urldata())
             if not match:
                 yield ServiceError("Cant find any media on that page")
                 return
@@ -42,12 +39,12 @@ class NHL(Service, OpenGraphThumbMixin):
             except KeyError:
                 yield ServiceError("Can't find api url")
                 return
-            filename = "{0}?contentId={1}&playbackScenario=HTTP_CLOUD_WIRED_WEB&format=json&platform=WEB_MEDIAPLAYER&_=1487455224334".format(janson["vpm"]["mediaFramework"]["mediaFrameworkEndPoint"], vid)
+            filename = "{0}?contentId={1}&playbackScenario=HTTP_CLOUD_WIRED_WEB&format=json&platform=WEB_MEDIAPLAYER" \
+                       "&_=1487455224334".format(janson["vpm"]["mediaFramework"]["mediaFrameworkEndPoint"], vid)
             url = urljoin(apiurl, filename)
             res = self.http.get(url)
             janson = res.json()
             for i in janson["user_verified_event"][0]["user_verified_content"][0]["user_verified_media_item"]:
-                streams = hlsparse(self.options, self.http.request("get", i["url"]), i["url"])
-                if streams:
-                    for n in list(streams.keys()):
-                        yield streams[n]
+                streams = hlsparse(self.config, self.http.request("get", i["url"]), i["url"], output=self.output)
+                for n in list(streams.keys()):
+                    yield streams[n]
