@@ -4,12 +4,12 @@ from __future__ import absolute_import
 import re
 import json
 import copy
+from urllib.parse import urlparse
 
 from svtplay_dl.service import Service, OpenGraphThumbMixin
 from svtplay_dl.fetcher.hls import hlsparse
 from svtplay_dl.fetcher.http import HTTP
 from svtplay_dl.error import ServiceError
-from svtplay_dl.utils.urllib import urlparse
 
 
 class Picsearch(Service, OpenGraphThumbMixin):
@@ -18,10 +18,6 @@ class Picsearch(Service, OpenGraphThumbMixin):
     def get(self):
         self.backupapi = None
 
-        if self.exclude():
-            yield ServiceError("Excluding video")
-            return
-
         ajax_auth = self.get_auth()
         if not ajax_auth:
             yield ServiceError("Cant find token for video")
@@ -34,21 +30,23 @@ class Picsearch(Service, OpenGraphThumbMixin):
         if not isinstance(mediaid, str):
             mediaid = mediaid.group(1)
 
-        jsondata = self.http.request("get", "http://csp.screen9.com/player?eventParam=1&ajaxauth={0}&method=embed&mediaid={1}".format(ajax_auth.group(1), mediaid)).text
+        jsondata = self.http.request("get", "http://csp.screen9.com/player?eventParam=1&"
+                                            "ajaxauth={0}&method=embed&mediaid={1}".format(ajax_auth.group(1), mediaid)).text
         jsondata = json.loads(jsondata)
 
         if "data" in jsondata:
             if "live" in jsondata["data"]["publishing_status"]:
-                self.options.live = jsondata["data"]["publishing_status"]["live"]
+                self.config.set("live", jsondata["data"]["publishing_status"]["live"])
             playlist = jsondata["data"]["streams"]
             for i in playlist:
                     if "application/x-mpegurl" in i:
-                        streams = hlsparse(self.options, self.http.request("get", i["application/x-mpegurl"]), i["application/x-mpegurl"])
+                        streams = hlsparse(self.config, self.http.request("get", i["application/x-mpegurl"]),
+                                           i["application/x-mpegurl"], output=self.output)
                         if streams:
                             for n in list(streams.keys()):
                                 yield streams[n]
                     if "video/mp4" in i:
-                        yield HTTP(copy.copy(self.options), i["video/mp4"], 800)
+                        yield HTTP(copy.copy(self.config), i["video/mp4"], 800, output=self.output)
 
         if self.backupapi:
             res = self.http.get(self.backupapi.replace("i=", ""), params={"i": "object"})
@@ -57,10 +55,9 @@ class Picsearch(Service, OpenGraphThumbMixin):
             jansson = json.loads(data)
             for i in jansson["media"]["playerconfig"]["playlist"]:
                 if "provider" in i and i["provider"] == "httpstreaming":
-                    streams = hlsparse(self.options, self.http.request("get", i["url"]), i["url"])
-                    if streams:
-                        for n in list(streams.keys()):
-                            yield streams[n]
+                    streams = hlsparse(self.config, self.http.request("get", i["url"]), i["url"], output=self.output)
+                    for n in list(streams.keys()):
+                        yield streams[n]
 
     def get_auth(self):
         match = re.search(r"picsearch_ajax_auth[ ]*=[ ]*['\"]([^'\"]+)['\"]", self.get_urldata())
