@@ -1,18 +1,19 @@
 from __future__ import absolute_import
 import re
+import copy
 from svtplay_dl.fetcher.hls import hlsparse
+from svtplay_dl.fetcher.http import HTTP
 
 
 from svtplay_dl.service import Service, OpenGraphThumbMixin
-
 from svtplay_dl.error import ServiceError
 
 
 class Riksdagen(Service, OpenGraphThumbMixin):
-    supported_domains_re = ["www.riksdagen.se"]
+    supported_domains_re = ["riksdagen.se", "www.riksdagen.se"]
 
     def get(self):
-        match = re.search("_([A-Z0-9]+)$", self.url)
+        match = re.search("_([a-zA-Z0-9]+)$", self.url)
         if not match:
             yield ServiceError("Cant find video id.")
             return
@@ -30,7 +31,9 @@ class Riksdagen(Service, OpenGraphThumbMixin):
         for i in janson:
             if i["mimetype"] == "application/x-mpegurl":
                 data2 = self.http.get(i["url"]).json()
-                streams = hlsparse(self.options, self.http.request("get", data2["url"]), data2["url"])
-                if streams:
-                    for n in list(streams.keys()):
-                        yield streams[n]
+                streams = hlsparse(self.config, self.http.request("get", data2["url"]), data2["url"], output=self.output)
+                for n in list(streams.keys()):
+                    yield streams[n]
+            if i["mimetype"] == "video/mp4":
+                for n in i["bandwidth"]:
+                    yield HTTP(copy.copy(self.config), n["url"], n["quality"], output=self.output)
