@@ -17,18 +17,14 @@ class Ruv(Service):
     def get(self):
         data = self.get_urldata()
 
-        if self.exclude():
-            yield ServiceError("Excluding video")
-            return
-
         match = re.search(r'"([^"]+geo.php)"', data)
         if match:
             data = self.http.request("get", match.group(1)).content
             match = re.search(r'punktur=\(([^ ]+)\)', data)
             if match:
                 janson = json.loads(match.group(1))
-                self.options.live = checklive(janson["result"][1])
-                streams = hlsparse(self.options, self.http.request("get", janson["result"][1]), janson["result"][1])
+                self.config.get("live", checklive(janson["result"][1]))
+                streams = hlsparse(self.config, self.http.request("get", janson["result"][1]), janson["result"][1], output=self.output)
                 for n in list(streams.keys()):
                     yield streams[n]
             else:
@@ -39,12 +35,12 @@ class Ruv(Service):
                 yield ServiceError("Can't find video info for: %s" % self.url)
                 return
             if match.group(1).endswith("mp4"):
-                yield HTTP(copy.copy(self.options), match.group(1), 800)
+                yield HTTP(copy.copy(self.config), match.group(1), 800, output=self.output)
             else:
                 m3u8_url = match.group(1)
-                self.options.live = checklive(m3u8_url)
-                yield HLS(copy.copy(self.options), m3u8_url, 800)
+                self.config.set("live", checklive(m3u8_url))
+                yield HLS(copy.copy(self.config), m3u8_url, 800, output=self.output)
 
 
 def checklive(url):
-    return True if re.search("live", url) else False
\ No newline at end of file
+    return True if re.search("live", url) else False
