@@ -1,5 +1,4 @@
 import re
-import json
 
 from svtplay_dl.error import ServiceError
 from svtplay_dl.service.svtplay import Svtplay
@@ -9,17 +8,19 @@ class Svt(Svtplay):
     supported_domains = ['svt.se', 'www.svt.se']
 
     def get(self):
-        match = re.search("window.svt.nyh.reduxState=({.*});", self.get_urldata())
-        if not match:
+
+        data = self.get_urldata()
+        match_data_video_id = re.search("data-video-id=\"(.+?)\"", data)
+
+        if match_data_video_id:
+            id = match_data_video_id.group(1)
+
+        else:
             yield ServiceError("Cant find video info.")
             return
 
-        janson = json.loads(match.group(1))
-        context = janson["appState"]["location"]["context"]
-        areaData = janson["areaData"]["articles"][context]["media"]
-
-        res = self.http.get("http://api.svt.se/videoplayer-api/video/{0}".format(areaData[0]["id"]))
+        res = self.http.get("http://api.svt.se/videoplayer-api/video/{0}".format(id))
         janson = res.json()
         videos = self._get_video(janson)
         for i in videos:
-            yield i
\ No newline at end of file
+            yield i
