@@ -7,12 +7,10 @@
 from __future__ import absolute_import
 import re
 import json
-import os
 import copy
+from urllib.parse import urlparse, quote_plus
 
-from svtplay_dl.utils.urllib import urlparse, quote_plus
 from svtplay_dl.service import Service
-from svtplay_dl.utils import filenamify
 from svtplay_dl.log import log
 from svtplay_dl.fetcher.hls import hlsparse
 from svtplay_dl.fetcher.http import HTTP
@@ -49,21 +47,17 @@ class Twitch(Service):
     def get(self):
         urlp = urlparse(self.url)
 
-        if self.exclude():
-            yield ServiceError("Excluding video")
-            return
-
         match = re.match(r'/(\w+)/([bcv])/(\d+)', urlp.path)
         if not match:
             if re.search("clips.twitch.tv", urlp.netloc):
-                data = self._get_clips(self.options)
+                data = self._get_clips()
             else:
-                data = self._get_channel(self.options, urlp)
+                data = self._get_channel(urlp)
         else:
             if match.group(2) in ["b", "c"]:
                 yield ServiceError("This twitch video type is unsupported")
                 return
-            data = self._get_archive(self.options, match.group(3))
+            data = self._get_archive(match.group(3))
         try:
             for i in data:
                 yield i
@@ -71,20 +65,16 @@ class Twitch(Service):
             yield ServiceError("This twitch video type is unsupported")
             return
 
-    def _get_static_video(self, options, videoid):
+    def _get_static_video(self, videoid):
         access = self._get_access_token(videoid)
 
-        if options.output_auto:
-            data = self.http.request("get", "https://api.twitch.tv/kraken/videos/v{0}".format(videoid))
-            if data.status_code == 404:
-                yield ServiceError("Can't find the video")
-                return
-            info = json.loads(data.text)
-            name = "twitch-{0}-{1}".format(info["channel"]["name"], filenamify(info["title"]))
-            directory = os.path.dirname(options.output)
-            if os.path.isdir(directory):
-                name = os.path.join(directory, name)
-            options.output = name
+        data = self.http.request("get", "https://api.twitch.tv/kraken/videos/v{0}".format(videoid))
+        if data.status_code == 404:
+            yield ServiceError("Can't find the video")
+            return
+        info = json.loads(data.text)
+        self.output["title"] = "twitch-{0}".format(info["channel"]["name"])
+        self.output["episodename"] = info["title"]
 
         if "token" not in access:
             raise TwitchUrlException('video', self.url)
@@ -93,14 +83,14 @@ class Twitch(Service):
 
         url = "http://usher.twitch.tv/vod/{0}?nauth={1}&nauthsig={2}".format(videoid, nauth, authsig)
 
-        streams = hlsparse(options, self.http.request("get", url), url)
+        streams = hlsparse(copy.copy(self.config), self.http.request("get", url), url, output=self.output)
         if streams:
             for n in list(streams.keys()):
                 yield streams[n]
 
-    def _get_archive(self, options, vid):
+    def _get_archive(self, vid):
         try:
-            for n in self._get_static_video(options, vid):
+            for n in self._get_static_video(vid):
                 yield n
         except TwitchUrlException as e:
             log.error(str(e))
@@ -139,44 +129,38 @@ class Twitch(Service):
         query = "token={0}&sig={1}&allow_source=true&allow_spectre=true".format(quote_plus(access['token']), access['sig'])
         return "{0}/{1}.m3u8?{2}".format(self.hls_base_url, channel, query)
 
-    def _get_channel(self, options, urlp):
+    def _get_channel(self, urlp):
         match = re.match(r'/(\w+)', urlp.path)
 
         if not match:
             raise TwitchUrlException('channel', urlp.geturl())
 
         channel = match.group(1)
-        if options.output_auto:
-            options.output = "twitch-{0}".format(channel)
+
+        self.output["title"] = channel
 
         hls_url = self._get_hls_url(channel)
         urlp = urlparse(hls_url)
 
-        options.live = True
-        if not options.output:
-            options.output = channel
+        self.config.set("live", True)
         data = self.http.request("get", hls_url)
         if data.status_code == 404:
             yield ServiceError("Stream is not online.")
             return
-        streams = hlsparse(options, data, hls_url)
+        streams = hlsparse(self.output, data, hls_url, output=self.output)
         for n in list(streams.keys()):
             yield streams[n]
 
-    def _get_clips(self, options):
-        match = re.search("quality_options: (\[[^\]]+\])", self.get_urldata())
+    def _get_clips(self):
+        match = re.search(r"quality_options: (\[[^\]]+\])", self.get_urldata())
         if not match:
             yield ServiceError("Can't find the video clip")
             return
-        if options.output_auto:
-            name = re.search('slug: "([^"]+)"', self.get_urldata()).group(1)
-            brodcaster = re.search('broadcaster_login: "([^"]+)"', self.get_urldata()).group(1)
-            name = "twitch-{0}-{1}".format(brodcaster, name)
-            directory = os.path.dirname(options.output)
-            if os.path.isdir(directory):
-                name = os.path.join(directory, name)
-            options.output = name
+        name = re.search(r'slug: "([^"]+)"', self.get_urldata()).group(1)
+        brodcaster = re.search('broadcaster_login: "([^"]+)"', self.get_urldata()).group(1)
+        self.output["title"] = "twitch-{0}".format(brodcaster)
+        self.output["episodename"] = name
 
         dataj = json.loads(match.group(1))
         for i in dataj:
-            yield HTTP(copy.copy(options), i["source"], i["quality"])
+            yield HTTP(copy.copy(self.config), i["source"], i["quality"], output=self.output)
