@@ -8,12 +8,9 @@ from __future__ import absolute_import
 import re
 import json
 import copy
-import os
+from urllib.parse import urlparse
 
-from svtplay_dl.utils import filenamify
-from svtplay_dl.utils.urllib import urlparse
 from svtplay_dl.service import Service, OpenGraphThumbMixin
-from svtplay_dl.fetcher.rtmp import RTMP
 from svtplay_dl.fetcher.hds import hdsparse
 from svtplay_dl.fetcher.hls import hlsparse
 from svtplay_dl.subtitle import subtitle
@@ -55,25 +52,31 @@ class Viaplay(Service, OpenGraphThumbMixin):
             jansson = json.loads(match.group(1))
             if "seasonNumberOrVideoId" in jansson:
                 season = jansson["seasonNumberOrVideoId"]
-                match = re.search("\w-(\d+)$", season)
+                match = re.search(r"\w-(\d+)$", season)
                 if match:
                     season = match.group(1)
             else:
-                return False
+                match = self._conentpage(self.get_urldata())
+                if match:  # this only happen on the program page?
+                    janson2 = json.loads(match.group(1))
+                    if janson2["formatPage"]["format"]:
+                        season = janson2["formatPage"]["format"]["seasonNumber"]
+                        return janson2["formatPage"]["format"]["videos"][str(season)]["program"][0]["id"]
+                return None
             if "videoIdOrEpisodeNumber" in jansson:
                 videp = jansson["videoIdOrEpisodeNumber"]
-                match = re.search('(\w+)-(\d+)', videp)
+                match = re.search(r'(\w+)-(\d+)', videp)
                 if match:
                     episodenr = match.group(2)
                 else:
                     episodenr = videp
                     clips = True
-                match = re.search('(s\w+)-(\d+)', season)
+                match = re.search(r'(s\w+)-(\d+)', season)
                 if match:
                     season = match.group(2)
             else:
                 # sometimes videoIdOrEpisodeNumber does not work.. this is a workaround
-                match = re.search('(episode|avsnitt)-(\d+)', self.url)
+                match = re.search(r'(episode|avsnitt)-(\d+)', self.url)
                 if match:
                     episodenr = match.group(2)
                 else:
@@ -87,9 +90,9 @@ class Viaplay(Service, OpenGraphThumbMixin):
                 match = self._conentpage(self.get_urldata())
                 if match:
                     janson = json.loads(match.group(1))
-                    for i in janson["format"]["videos"].keys():
-                        if "program" in janson["format"]["videos"][str(i)]:
-                            for n in janson["format"]["videos"][i]["program"]:
+                    for i in janson["formatPage"]["format"]["videos"].keys():
+                        if "program" in janson["formatPage"]["format"]["videos"][str(i)]:
+                            for n in janson["formatPage"]["format"]["videos"][i]["program"]:
                                 if str(n["episodeNumber"]) and int(episodenr) == n["episodeNumber"] and int(season) == n["seasonNumber"]:
                                     if slug is None or slug == n["formatSlug"]:
                                         return n["id"]
@@ -103,15 +106,27 @@ class Viaplay(Service, OpenGraphThumbMixin):
         match = re.search(r'iframe src="http://play.juicyplay.se[^\"]+id=(\d+)', html_data)
         if match:
             return match.group(1)
+
+        match = re.search(r'<meta property="og:image" content="([\S]+)"', html_data)
+        if match:
+            return match.group(1).split("/")[-2]
+
         return None
 
     def get(self):
+        parse = urlparse(self.url)
         vid = self._get_video_id()
         if vid is None:
-            yield ServiceError("Can't find video file for: {0}".format(self.url))
-            return
+            if parse.path[:6] == "/sport":
+                result = self._sport()
+                for i in result:
+                    yield i
+                return
+            else:
+                yield ServiceError("Can't find video file for: {0}".format(self.url))
+                return
 
-        data = self. _get_video_data(vid)
+        data = self._get_video_data(vid)
         if data.status_code == 403:
             yield ServiceError("Can't play this because the video is geoblocked.")
             return
@@ -122,14 +137,10 @@ class Viaplay(Service, OpenGraphThumbMixin):
             return
 
         if dataj["type"] == "live":
-            self.options.live = True
+            self.config.set("live", True)
 
-        if self.options.output_auto:
-            self.options.output = self.outputfilename(dataj, vid, self.options.output)
-
-        if self.exclude():
-            yield ServiceError("Excluding video")
-            return
+        self.output["id"] = vid
+        self._autoname(dataj)
 
         streams = self.http.request("get", "http://playapi.mtgx.tv/v3/videos/stream/{0}".format(vid))
         if streams.status_code == 403:
@@ -146,66 +157,57 @@ class Viaplay(Service, OpenGraphThumbMixin):
                 subtype = "wrst"
             else:
                 subtype = "sami"
-            yield subtitle(copy.copy(self.options), subtype, dataj["sami_path"])
+            yield subtitle(copy.copy(self.config), subtype, dataj["sami_path"], output=self.output)
         if dataj["subtitles_webvtt"]:
-            yield subtitle(copy.copy(self.options), "wrst", dataj["subtitles_webvtt"])
+            yield subtitle(copy.copy(self.config), "wrst", dataj["subtitles_webvtt"], output=self.output)
         if dataj["subtitles_for_hearing_impaired"]:
             if dataj["subtitles_for_hearing_impaired"].endswith("vtt"):
                 subtype = "wrst"
             else:
                 subtype = "sami"
-            if self.options.get_all_subtitles:
-                yield subtitle(copy.copy(self.options), subtype, dataj["subtitles_for_hearing_impaired"], "-SDH")
+            if self.config.get("get_all_subtitles"):
+                yield subtitle(copy.copy(self.config), subtype, dataj["subtitles_for_hearing_impaired"], "-SDH", output=self.output)
             else:
-                yield subtitle(copy.copy(self.options), subtype, dataj["subtitles_for_hearing_impaired"])
+                yield subtitle(copy.copy(self.config), subtype, dataj["subtitles_for_hearing_impaired"], output=self.output)
 
-        if streamj["streams"]["medium"]:
+        if streamj["streams"]["medium"] and streamj["streams"]["medium"][:7] != "[empty]":
             filename = streamj["streams"]["medium"]
             if ".f4m" in filename:
-                streams = hdsparse(self.options, self.http.request("get", filename, params={"hdcore": "3.7.0"}), filename)
-                if streams:
-                    for n in list(streams.keys()):
-                        yield streams[n]
-            else:
-                parse = urlparse(filename)
-                match = re.search("^(/[^/]+)/(.*)", parse.path)
-                if not match:
-                    yield ServiceError("Can't get rtmpparse info")
-                    return
-                filename = "{0}://{1}:{2}{3}".format(parse.scheme, parse.hostname, parse.port, match.group(1))
-                path = "-y {0}".format(match.group(2))
-                self.options.other = "-W http://flvplayer.viastream.viasat.tv/flvplayer/play/swf/player.swf {0}".format(path)
-                yield RTMP(copy.copy(self.options), filename, 800)
-
-        if streamj["streams"]["hls"]:
-            streams = hlsparse(self.options, self.http.request("get", streamj["streams"]["hls"]), streamj["streams"]["hls"])
-            if streams:
+                streams = hdsparse(self.config, self.http.request("get", filename, params={"hdcore": "3.7.0"}),
+                                   filename, output=self.output)
                 for n in list(streams.keys()):
                     yield streams[n]
 
-    def find_all_episodes(self, options):
+        if streamj["streams"]["hls"]:
+            streams = hlsparse(self.config, self.http.request("get", streamj["streams"]["hls"]),
+                               streamj["streams"]["hls"], output=self.output)
+            for n in list(streams.keys()):
+                yield streams[n]
+
+    def find_all_episodes(self, config):
         seasons = []
-        match = re.search("(sasong|sesong)-(\d+)", urlparse(self.url).path)
+        match = re.search(r"(sasong|sesong)-(\d+)", urlparse(self.url).path)
         if match:
             seasons.append(match.group(2))
         else:
             match = self._conentpage(self.get_urldata())
             if match:
                 janson = json.loads(match.group(1))
-                for i in janson["format"]["seasons"]:
+                for i in janson["formatPage"]["format"]["seasons"]:
                     seasons.append(i["seasonNumber"])
 
-        episodes = self._grab_episodes(options, seasons)
-        if options.all_last > 0:
-            return episodes[-options.all_last:]
+        episodes = self._grab_episodes(config, seasons)
+        if config.get("all_last") > 0:
+            return episodes[-config.get("all_last"):]
         return sorted(episodes)
 
-    def _grab_episodes(self, options, seasons):
+    def _grab_episodes(self, config, seasons):
         episodes = []
         baseurl = self.url
-        match = re.search("(saeson|sasong|sesong)-\d+", urlparse(self.url).path)
+        match = re.search(r"(saeson|sasong|sesong)-\d+", urlparse(self.url).path)
         if match:
-            baseurl = self.url[:self.url.rfind("/")]
+            if re.search(r"(avsnitt|episode)", urlparse(baseurl).path):
+                baseurl = baseurl[:baseurl.rfind("/")]
             baseurl = baseurl[:baseurl.rfind("/")]
 
         for i in seasons:
@@ -215,55 +217,38 @@ class Viaplay(Service, OpenGraphThumbMixin):
                 match = self._conentpage(res.text)
                 if match:
                     janson = json.loads(match.group(1))
-                    if "program" in janson["format"]["videos"][str(i)]:
-                        for n in janson["format"]["videos"][str(i)]["program"]:
+                    if "program" in janson["formatPage"]["format"]["videos"][str(i)]:
+                        for n in janson["formatPage"]["format"]["videos"][str(i)]["program"]:
                             episodes = self._videos_to_list(n["sharingUrl"], n["id"], episodes)
-                    if options.include_clips:
-                        if "clip" in janson["format"]["videos"][str(i)]:
-                            for n in janson["format"]["videos"][str(i)]["clip"]:
+                    if config.get("include_clips"):
+                        if "clip" in janson["formatPage"]["format"]["videos"][str(i)]:
+                            for n in janson["formatPage"]["format"]["videos"][str(i)]["clip"]:
                                 episodes = self._videos_to_list(n["sharingUrl"], n["id"], episodes)
         return episodes
 
     def _isswe(self, url):
-        if re.search(".se$", urlparse(url).netloc):
+        if re.search(r".se$", urlparse(url).netloc):
             return "sasong"
-        elif re.search(".dk$", urlparse(url).netloc):
+        elif re.search(r".dk$", urlparse(url).netloc):
             return "saeson"
         else:
             return "sesong"
 
     def _conentpage(self, data):
-        return re.search('"ContentPageProgramStore":({.*}),[ ]*"ApplicationStore', data)
+        return re.search(r'=({"sportsPlayer.*}); window.__config', data)
 
     def _videos_to_list(self, url, vid, episodes):
         dataj = json.loads(self._get_video_data(vid).text)
         if "msg" not in dataj:
-            filename = self.outputfilename(dataj, vid, self.options.output)
-            if not self.exclude2(filename) and url not in episodes:
+            if url not in episodes:
                 episodes.append(url)
         return episodes
 
     def _get_video_data(self, vid):
         url = "http://playapi.mtgx.tv/v3/videos/{0}".format(vid)
-        self.options.other = ""
         data = self.http.request("get", url)
         return data
 
-    def outputfilename(self, data, vid, filename):
-        self.options.service = "viafree"
-        if filename:
-            directory = os.path.dirname(filename)
-        else:
-            directory = ""
-
-        basename = self._autoname(data)
-        title = "{0}-{1}-{2}".format(basename, vid, self.options.service)
-        if len(directory):
-            output = os.path.join(directory, title)
-        else:
-            output = title
-        return output
-
     def _autoname(self, dataj):
         program = dataj["format_slug"]
         season = None
@@ -271,28 +256,30 @@ class Viaplay(Service, OpenGraphThumbMixin):
         title = None
 
         if "season" in dataj["format_position"]:
-            if dataj["format_position"]["season"] > 0:
+            if dataj["format_position"]["season"] and dataj["format_position"]["season"] > 0:
                 season = dataj["format_position"]["season"]
         if season:
-            if len(dataj["format_position"]["episode"]) > 0:
+            if dataj["format_position"]["episode"] and len(dataj["format_position"]["episode"]) > 0:
                 episode = dataj["format_position"]["episode"]
             if episode:
                 try:
                     episode = int(episode)
-                except TypeError:
-                    title = filenamify(episode)
+                except (TypeError, ValueError):
+                    title = episode
                     episode = None
             else:
-                title = filenamify(dataj["title"])
+                title = dataj["summary"].replace("{} - ".format(dataj["format_title"]), "")
+                if title[-1] == ".":
+                    title = title[:len(title) - 1]  # remove the last dot
 
         if dataj["type"] == "clip":
             # Removes the show name from the end of the filename
             # e.g. Showname.S0X.title instead of Showname.S07.title-showname
             match = re.search(r'(.+)-', dataj["title"])
             if match:
-                title = filenamify(match.group(1))
+                title = match.group(1)
             else:
-                title = filenamify(dataj["title"])
+                title = dataj["title"]
             if "derived_from_id" in dataj:
                 if dataj["derived_from_id"]:
                     parent_id = dataj["derived_from_id"]
@@ -304,12 +291,34 @@ class Viaplay(Service, OpenGraphThumbMixin):
                         if len(datajparent["format_position"]["episode"]) > 0:
                             episode = datajparent["format_position"]["episode"]
 
-        name = filenamify(program)
-        if season:
-            name = "{0}.s{1:02d}".format(name, int(season))
-        if episode:
-            name = "{0}e{1:02d}".format(name, int(episode))
-        if title:
-            name = "{0}.{1}".format(name, title)
+        self.output["title"] = program
+        self.output["season"] = season
+        self.output["episode"] = episode
+        self.output["episodename"] = title
 
-        return name
+        return True
+
+    def _sport(self):
+        content = self._conentpage(self.get_urldata())
+        if not content:
+            yield ServiceError("Can't find video file for: {0}".format(self.url))
+            return
+
+        janson = json.loads(content.group(1))
+        if not janson["sportsPlayer"]["currentVideo"]:
+            yield ServiceError("Can't find video file for: {0}".format(self.url))
+            return
+
+        self.output["title"] = janson["sportsPlayer"]["currentVideo"]["title"]
+
+        res = self.http.request("get", janson["sportsPlayer"]["currentVideo"]["_links"]["streamLink"]["href"])
+        if res.status_code == 403:
+            yield ServiceError("Can't play this because the video is geoblocked.")
+            return
+
+        for i in res.json()["embedded"]["prioritizedStreams"]:
+            streams = hlsparse(self.config, self.http.request("get", i["links"]["stream"]["href"]),
+                               i["links"]["stream"]["href"], output=self.output)
+            if streams:
+                for n in list(streams.keys()):
+                    yield streams[n]
