@@ -1,26 +1,35 @@
 import xml.etree.ElementTree as ET
 import json
 import re
+from io import StringIO
+
 from svtplay_dl.log import log
-from svtplay_dl.utils import is_py2, is_py3, decode_html_entities, HTTP
-from svtplay_dl.utils.io import StringIO
-from svtplay_dl.output import output
+from svtplay_dl.utils.text import decode_html_entities
+from svtplay_dl.utils.http import HTTP, get_full_url
+from svtplay_dl.utils.output import output
+
+
 from requests import __build__ as requests_version
 import platform
 
 
 class subtitle(object):
-    def __init__(self, options, subtype, url, subfix=None):
+    def __init__(self, config, subtype, url, subfix=None, **kwargs):
         self.url = url
         self.subtitle = None
-        self.options = options
+        self.config = config
         self.subtype = subtype
-        self.http = HTTP(options)
+        self.http = HTTP(config)
         self.subfix = subfix
         self.bom = False
+        self.output = kwargs.pop("output", None)
+        self.kwargs = kwargs
+
+    def __repr__(self):
+        return "<Subtitle(type={}, url={}>".format(self.subtype, self.url)
 
     def download(self):
-        subdata = self.http.request("get", self.url, cookies=self.options.cookies)
+        subdata = self.http.request("get", self.url)
         if subdata.status_code != 200:
             log.warning("Can't download subtitle file")
             return
@@ -45,42 +54,41 @@ class subtitle(object):
             if "dplay" in self.url:
                 subdata.encoding = "utf-8"
             data = self.wrst(subdata)
+        if self.subtype == "wrstsegment":
+            data = self.wrstsegment(subdata)
         if self.subtype == "raw":
             data = self.raw(subdata)
 
         if self.subfix:
-            self.options.output = self.options.output + self.subfix
+            if self.config.get("get_all_subtitles"):
+                if self.output["episodename"]:
+                    self.output["episodename"] = "{}-{}".format(self.output["episodename"], self.subfix)
+                else:
+                    self.output["episodename"] = self.subfix
 
-        if self.options.get_raw_subtitles:
+        if self.config.get("get_raw_subtitles"):
             subdata = self.raw(subdata)
             self.save_file(subdata, self.subtype)
 
         self.save_file(data, "srt")
 
     def save_file(self, data, subtype):
-        if platform.system() == "Windows" and is_py3:
-            file_d = output(self.options, subtype, mode="wt", encoding="utf-8")
+        if platform.system() == "Windows":
+            file_d = output(self.output, self.config, subtype, mode="wt", encoding="utf-8")
         else:
-            file_d = output(self.options, subtype, mode="wt")
+            file_d = output(self.output, self.config, subtype, mode="wt")
         if hasattr(file_d, "read") is False:
             return
         file_d.write(data)
         file_d.close()
 
     def raw(self, subdata):
-        if is_py2:
-            data = subdata.text.encode("utf-8")
-        else:
-            data = subdata.text
-        return data
+        return subdata.text
 
     def tt(self, subdata):
         i = 1
         data = ""
-        if is_py2:
-            subs = subdata.text.encode("utf8")
-        else:
-            subs = subdata.text
+        subs = subdata.text
 
         subdata = re.sub(' xmlns="[^"]+"', '', subs, count=1)
         tree = ET.XML(subdata)
@@ -108,8 +116,7 @@ class subtitle(object):
                 data = tt_text(node, data)
                 data += "\n"
                 i += 1
-        if is_py2:
-            data = data.encode("utf8")
+
         return data
 
     def json(self, subdata):
@@ -118,46 +125,40 @@ class subtitle(object):
         subs = ""
         for i in data:
             subs += "%s\n%s --> %s\n" % (number, timestr(int(i["startMillis"])), timestr(int(i["endMillis"])))
-            if is_py2:
-                subs += "%s\n\n" % i["text"].encode("utf-8")
-            else:
-                subs += "%s\n\n" % i["text"]
+            subs += "%s\n\n" % i["text"]
             number += 1
 
         return subs
 
     def sami(self, subdata):
         text = subdata.text
-        if is_py2:
-            text = text.encode("utf8")
         text = re.sub(r'&', '&amp;', text)
         tree = ET.fromstring(text)
-        subt = tree.find("Font")
+        allsubs = tree.findall(".//Subtitle")
         subs = ""
-        n = 0
-        for i in subt.getiterator():
-            if i.tag == "Subtitle":
-                n = i.attrib["SpotNumber"]
+        increase = 0
+        for sub in allsubs:
+            try:
+                number = int(sub.attrib["SpotNumber"])
+            except ValueError:
+                number = int(re.search(r"(\d+)", sub.attrib["SpotNumber"]).group(1))
+                increase += 1
+            n = number + increase
 
-                if i.attrib["SpotNumber"] == "1":
-                    subs += "%s\n%s --> %s\n" % (i.attrib["SpotNumber"], timecolon(i.attrib["TimeIn"]), timecolon(i.attrib["TimeOut"]))
-                else:
-                    subs += "\n%s\n%s --> %s\n" % (i.attrib["SpotNumber"], timecolon(i.attrib["TimeIn"]), timecolon(i.attrib["TimeOut"]))
-            else:
-                if int(n) > 0 and i.text:
-                    subs += "%s\n" % decode_html_entities(i.text)
-
-        if is_py2:
-            subs = subs.encode('utf8')
+            texts = sub.findall(".//Text")
+            all = ""
+            for text in texts:
+                line = ""
+                for txt in text.itertext():
+                    line += "{}".format(txt)
+                all += "{}\n".format(decode_html_entities(line.lstrip()))
+            subs += "{}\n{} --> {}\n{}\n".format(n, timecolon(sub.attrib["TimeIn"]), timecolon(sub.attrib["TimeOut"]), all)
         subs = re.sub('&amp;', r'&', subs)
         return subs
 
     def smi(self, subdata):
         if requests_version < 0x20300:
-            if is_py2:
-                subdata = subdata.content
-            else:
-                subdata = subdata.content.decode("latin")
+            subdata = subdata.content.decode("latin")
         else:
             subdata.encoding = "ISO-8859-1"
             subdata = subdata.text
@@ -187,8 +188,6 @@ class subtitle(object):
                 data = text.group(1)
         recomp = re.compile(r'\r')
         text = bad_char.sub('-', recomp.sub('', subs))
-        if is_py2 and isinstance(text, unicode):
-            return text.encode("utf-8")
         return text
 
     def wrst(self, subdata):
@@ -243,9 +242,13 @@ class subtitle(object):
                 srt += "%s\n" % number
                 subnr = True
             else:
-                if self.options.convert_subtitle_colors:
-                    colors = {'30': '#000000', '31': '#ff0000', '32': '#00ff00', '33': '#ffff00',
-                              '34': '#0000ff', '35': '#ff00ff', '36': '#00ffff', '37': '#ffffff'}
+                if self.config.get("convert_subtitle_colors"):
+                    colors = {
+                        '30': '#000000', '31': '#ff0000', '32': '#00ff00', '33': '#ffff00', '34': '#0000ff',
+                        '35': '#ff00ff', '36': '#00ffff', '37': '#ffffff', 'c.black': '#000000', 'c.red': '#ff0000',
+                        'c.green': '#00ff00', 'c.yellow': '#ffff00', 'c.blue': '#0000ff', 'c.magneta': '#ff00ff',
+                        'c.cyan': '#00ffff', 'c.gray': '#ffffff',
+                    }
                     sub = i
                     for tag, color in colors.items():
                         regex1 = '<' + tag + '>'
@@ -258,10 +261,63 @@ class subtitle(object):
                 srt += sub.strip()
                 srt += "\n"
         srt = decode_html_entities(srt)
-        if is_py2:
-            return srt.encode("utf-8")
         return srt
 
+    def wrstsegment(self, subdata):
+        time = 0
+        subs = []
+        for i in self.kwargs["m3u8"].media_segment:
+            itemurl = get_full_url(i["URI"], self.url)
+            cont = self.http.get(itemurl)
+            if "cmore" in self.url:
+                cont.encoding = "utf-8"
+            text = cont.text.split("\n")
+            for t in text:  # is in text[1] for tv4play, but this should be more future proof
+                if 'X-TIMESTAMP-MAP=MPEGTS' in t:
+                    time = float(re.search(r"X-TIMESTAMP-MAP=MPEGTS:(\d+)", t).group(1)) / 90000 - 10
+            text = text[3:len(text) - 2]
+            if len(text) > 1:
+                itmes = []
+                for n in text:
+                    if n:
+                        itmes.append(n)
+                    else:
+                        if len(subs) > 1 and len(itmes) < 2:  # Ignore empty lines in unexpected places
+                            pass
+                        elif len(subs) > 1 and itmes[1] == subs[-1][1]:  # This will happen when there are two sections in file
+                            ha = strdate(subs[-1][0])
+                            ha3 = strdate(itmes[0])
+                            second = str2sec(ha3.group(2)) + time
+                            subs[-1][0] = "{} --> {}".format(ha.group(1), sec2str(second))
+                            itmes = []
+                        else:
+                            ha = strdate(itmes[0])
+                            first = str2sec(ha.group(1)) + time
+                            second = str2sec(ha.group(2)) + time
+                            itmes[0] = "{} --> {}".format(sec2str(first), sec2str(second))
+                            subs.append(itmes)
+                            itmes = []
+                if itmes:
+                    if len(subs) > 0 and itmes[1] == subs[-1][1]:
+                        ha = strdate(subs[-1][0])
+                        ha3 = strdate(itmes[0])
+                        second = str2sec(ha3.group(2)) + time
+                        subs[-1][0] = "{} --> {}".format(ha.group(1), sec2str(second))
+                    else:
+                        ha = strdate(itmes[0])
+                        first = str2sec(ha.group(1)) + time
+                        second = str2sec(ha.group(2)) + time
+                        itmes[0] = "{} --> {}".format(sec2str(first), sec2str(second))
+                        subs.append(itmes)
+
+        string = ""
+        nr = 1
+        for sub in subs:
+            string += "{}\n{}\n\n".format(nr, '\n'.join(sub))
+            nr += 1
+
+        return string
+
 
 def timestr(msec):
     """
@@ -309,3 +365,18 @@ def tt_text(node, data):
             if text:
                 data += "%s\n" % text
     return data
+
+
+def strdate(datestring):
+    match = re.search(r"^(\d+:\d+:[\.0-9]+) --> (\d+:\d+:[\.0-9]+)", datestring)
+    return match
+
+
+def sec2str(seconds):
+    m, s = divmod(seconds, 60)
+    h, m = divmod(m, 60)
+    return "{:02d}:{:02d}:{:06.3f}".format(int(h), int(m), s)
+
+
+def str2sec(string):
+    return sum(x * float(t) for x, t in zip([3600, 60, 1], string.split(":")))
